Module analyzer

Module analyzer 

Core BPM analysis functionality.

Functions

begin
Starts the BPM analyzer with the given configuration using the default device.
begin_with_device
Starts the BPM analyzer with the given configuration and a specific audio device.