Core BPM analysis functionality.
Functions
- begin
- Starts the BPM analyzer with the given configuration using the default device.
- begin_
with_ device - Starts the BPM analyzer with the given configuration and a specific audio device.